==> aria2-1.12.0.tar.xz: aria2-1.12.0/src/SingletonHolder.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_SINGLETON_HOLDER_H
#define D_SINGLETON_HOLDER_H

namespace aria2 {

template<typename T>
class SingletonHolder {
private:
  static T instance_;

  SingletonHolder() {}
public:
  ~SingletonHolder() {}

  static T& instance()
  {
    return instance_;
  }

  static void instance(T& instance)
  {
    instance_ = instance;
  }
};

template<typename T>
T SingletonHolder<T>::instance_;

} // namespace aria2

#endif // D_SINGLETON_HOLDER_H

==> aria2-1.17.1.tar.xz: aria2-1.17.1/src/SingletonHolder.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_SINGLETON_HOLDER_H
#define D_SINGLETON_HOLDER_H

#include "SharedHandle.h"

namespace aria2 {

template<typename T>
class SingletonHolder {
private:
  static SharedHandle<T> instance_;

  SingletonHolder() {}
public:
  ~SingletonHolder() {}

  static const SharedHandle<T>& instance()
  {
    return instance_;
  }

  static void instance(const SharedHandle<T>& instance)
  {
    instance_ = instance;
  }

  static void clear()
  {
    instance_.reset();
  }
};

template<typename T>
SharedHandle<T> SingletonHolder<T>::instance_;

} // namespace aria2

#endif // D_SINGLETON_HOLDER_H
